@@ -29,6 +29,7 @@
 #include "weather-presets.h"
 #include "weather-home.h"
 #include "weather-utils.h"
+#include <values.h>
 /*******************************************************************************/
 void
 composition_right_horizontal_day_button(WDB *new_day_button){
@@ -49,7 +50,7 @@ composition_right_horizontal_day_button(WDB *new_day_button){
     /* background */
     memset(buffer, 0, sizeof(buffer));
     snprintf(buffer, sizeof(buffer) - 1, "%s%s", IMAGES_PATH, PRESET_RIGHT_HORIZONTAL_BACKGROUND);
-//    new_day_button->background = gtk_image_new_from_file (buffer);
+    new_day_button->background = gtk_image_new_from_file (buffer);
 
     gtk_widget_set_size_request(new_day_button->box, 70, 177);
     if (new_day_button->background)
@@ -60,7 +61,7 @@ composition_right_horizontal_day_button(WDB *new_day_button){
         gtk_fixed_put(GTK_FIXED(new_day_button->box), new_day_button->wind, 0-5+14, 66-9);
     if (new_day_button->wind_text)
         gtk_fixed_put(GTK_FIXED(new_day_button->box), new_day_button->wind_text, 0+14+6, 66+0);
-/*
+
     day = gtk_label_new(NULL);
     day_name = (gchar*)gtk_label_get_text(GTK_LABEL(new_day_button->label));
 
@@ -99,7 +100,7 @@ composition_right_horizontal_day_button(WDB *new_day_button){
         set_font(temperature, PRESET_TEMPERATURE_FONT, -1);
       gtk_widget_set_size_request(temperature, 66, 60);
     }
-*/
+
     if (day)
             gtk_fixed_put(GTK_FIXED(new_day_button->box), day, 0, 60+37+10);
     if (temperature)
@@ -131,7 +132,7 @@ composition_central_horizontal_day_button(WDB *new_day_button)
     /* background */
     memset(buffer, 0, sizeof(buffer));
     snprintf(buffer, sizeof(buffer) - 1, "%s%s", IMAGES_PATH, PRESET_MIDDLE_HORIZONTAL_BACKGROUND);
-//    new_day_button->background = gtk_image_new_from_file (buffer);
+    new_day_button->background = gtk_image_new_from_file (buffer);
 
     gtk_widget_set_size_request(new_day_button->box, 70, 177);
     if (new_day_button->background)
@@ -142,7 +143,7 @@ composition_central_horizontal_day_button(WDB *new_day_button)
         gtk_fixed_put(GTK_FIXED(new_day_button->box), new_day_button->wind, 0-5+14, 66-9);
     if (new_day_button->wind_text)
         gtk_fixed_put(GTK_FIXED(new_day_button->box), new_day_button->wind_text, 0+14+6, 66+0);
-/*
+
     day = gtk_label_new(NULL);
     day_name = (gchar*)gtk_label_get_text(GTK_LABEL(new_day_button->label));
 
@@ -186,7 +187,6 @@ composition_central_horizontal_day_button(WDB *new_day_button)
             gtk_fixed_put(GTK_FIXED(new_day_button->box), temperature, 0+2, 60+37+9+30);
 
     gtk_widget_destroy(new_day_button->label);
-    */
 #ifdef DEBUGFUNCTIONCALL
     END_FUNCTION;
 #endif
@@ -212,7 +212,7 @@ composition_central_vertical_day_button(WDB *new_day_button)
     /* background */
     memset(buffer, 0, sizeof(buffer));
     snprintf(buffer, sizeof(buffer) - 1, "%s%s", IMAGES_PATH, PRESET_LEFT_VERTICAL_BACKGROUND);
-//    new_day_button->background = gtk_image_new_from_file (buffer);
+    new_day_button->background = gtk_image_new_from_file (buffer);
 
     gtk_widget_set_size_request(new_day_button->box, 70, 200);
     if (new_day_button->background)
@@ -292,7 +292,7 @@ composition_left_vertical_day_button(WDB *new_day_button, gint layout)
     /* background */
     memset(buffer, 0, sizeof(buffer));
     snprintf(buffer, sizeof(buffer) - 1, "%s%s", IMAGES_PATH, PRESET_LEFT_VERTICAL_BACKGROUND);
-//    new_day_button->background = gtk_image_new_from_file (buffer);
+    new_day_button->background = gtk_image_new_from_file (buffer);
 
     day = gtk_label_new(NULL);
     day_name = (gchar*)gtk_label_get_text(GTK_LABEL(new_day_button->label));
@@ -388,7 +388,7 @@ composition_right_vertical_day_button(WDB *new_day_button, gint layout)
     /* background */
     memset(buffer, 0, sizeof(buffer));
     snprintf(buffer, sizeof(buffer) - 1, "%s%s", IMAGES_PATH, PRESET_RIGHT_VERTICAL_BACKGROUND);
-//    new_day_button->background = gtk_image_new_from_file (buffer);
+    new_day_button->background = gtk_image_new_from_file (buffer);
 
     day = gtk_label_new(NULL);
     day_name = (gchar*)gtk_label_get_text(GTK_LABEL(new_day_button->label));
@@ -476,7 +476,6 @@ composition_now(WDB *new_day_button, gint layout)
 #endif
 
     /* create day box to contain icon, label and wind image */
-    /*
     memset(buffer, 0, sizeof(buffer));
     switch (layout){
         case PRESET_NOW_PLUS_THREE_V:
@@ -507,26 +506,55 @@ composition_now(WDB *new_day_button, gint layout)
             gtk_widget_set_size_request(new_day_button->box, xoffset+140+1, 37+15+106);
             break;
     }
-    */
-//    new_day_button->background = gtk_image_new_from_file (buffer);
+    new_day_button->background = gtk_image_new_from_file (buffer);
 /* Packing all to the box */
     if (new_day_button->background)
-        gtk_fixed_put(GTK_FIXED(new_day_button->box), new_day_button->background, xoffset, 37+15);
+//        gtk_fixed_put(GTK_FIXED(new_day_button->box), new_day_button->background, xoffset, 37+15);
+        gtk_layout_put((new_day_button->box), new_day_button->background, xoffset, 37+15);
     if (new_day_button->icon_image)
-        gtk_fixed_put(GTK_FIXED(new_day_button->box), new_day_button->icon_image, 0+image_xoffset, 0);
+ //       gtk_fixed_put(GTK_FIXED(new_day_button->box), new_day_button->icon_image, 0+image_xoffset, 0);
+        gtk_layout_put((new_day_button->box), new_day_button->icon_image, 0+image_xoffset, 0);
     if (new_day_button->wind)
-        gtk_fixed_put(GTK_FIXED(new_day_button->box), new_day_button->wind, (87+14) + xoffset + wind_xoffset - 11, 5+37+10);
+    //    gtk_fixed_put(GTK_FIXED(new_day_button->box), new_day_button->wind, (87+14) + xoffset + wind_xoffset - 11, 5+37+10);
+        gtk_layout_put((new_day_button->box), new_day_button->wind, (87+14) + xoffset + wind_xoffset - 11, 5+37+10);
     if (new_day_button->wind_text)
-        gtk_fixed_put(GTK_FIXED(new_day_button->box), new_day_button->wind_text, (87+14) + xoffset + wind_xoffset, 7+37+18+1);
+  //      gtk_fixed_put(GTK_FIXED(new_day_button->box), new_day_button->wind_text, (87+14) + xoffset + wind_xoffset, 7+37+18+1);
+        gtk_layout_put((new_day_button->box), new_day_button->wind_text, (87+14) + xoffset + wind_xoffset, 7+37+18+1);
     if (new_day_button->shadow_label)
-        gtk_fixed_put(GTK_FIXED(new_day_button->box), new_day_button->shadow_label, xoffset+2, 60+37+15+2);
+      //  gtk_fixed_put(GTK_FIXED(new_day_button->box), new_day_button->shadow_label, xoffset+2, 60+37+15+2);
+        gtk_layout_put((new_day_button->box), new_day_button->shadow_label, xoffset+2, 60+37+15+2);
     if (new_day_button->label)
-        gtk_fixed_put(GTK_FIXED(new_day_button->box), new_day_button->label, xoffset, 60+37+15);
+      //  gtk_fixed_put(GTK_FIXED(new_day_button->box), new_day_button->label, xoffset, 60+37+15);
+        gtk_layout_put((new_day_button->box), new_day_button->label, xoffset, 60+37+15);
 #ifdef DEBUGFUNCTIONCALL
     END_FUNCTION;
 #endif
  
 }
+/*******************************************************************************/
+void
+realize (GtkWidget *widget)
+{
+    GdkPixmap *background;
+    GdkPixbuf *pixbuf;
+    GdkPixbuf *scaled;
+    GdkColormap *colormap;
+    GError *error=NULL;
+    GtkStyle *style;
+    gboolean boolit;
+    GdkScreen *screen;
+
+    screen = gtk_widget_get_screen (widget);
+    colormap = gdk_screen_get_rgba_colormap (screen);
+    gtk_widget_set_colormap (widget, colormap);
+    pixbuf=gdk_pixbuf_new_from_file("/usr/share/omweather/button_icons/nothing.png",&error);
+    scaled=gdk_pixbuf_scale_simple(pixbuf,700,700, GDK_INTERP_BILINEAR);
+    gdk_pixbuf_render_pixmap_and_mask_for_colormap(scaled,colormap,&background,NULL,0);
+    style = gtk_style_new();
+    style->bg_pixmap[0] = background;
+    gtk_widget_set_style(GTK_WIDGET(widget),GTK_STYLE(style));
+}
+   
 /*******************************************************************************/
 GtkWidget *
 next_station_preset_now(gint layout)
@@ -540,43 +568,54 @@ next_station_preset_now(gint layout)
     gchar           buffer[2048];
     gint            x_width = 0;
     gint            x_offset = 0;
-#ifdef DEBUGFUNCTIONCALL
+
+
+    GdkPixmap *background;
+
+//#ifdef DEBUGFUNCTIONCALL
     START_FUNCTION;
-#endif
-    widget = gtk_fixed_new();
+//#endif
+    //widget = gtk_fixed_new();
+    widget = gtk_layout_new(NULL, NULL);
+    gtk_widget_set_size_request(widget, 168, 74);
+    realize(widget);
     memset(buffer, 0, sizeof(buffer));
     switch (layout){
         case PRESET_NOW_PLUS_THREE_H:
         case PRESET_NOW_PLUS_SEVEN:
             snprintf(buffer, sizeof(buffer) - 1, "%s%s", IMAGES_PATH, PRESET_NOW_BACKGROUND_TOWN_HORIZONTAL);
-//            background_town = gtk_image_new_from_file (buffer);
+            background_town = gtk_image_new_from_file (buffer);
             if (background_town)
-                gtk_fixed_put(GTK_FIXED(widget), background_town, 12+15, 0);
+     //           gtk_fixed_put(GTK_FIXED(widget), background_town, 12+15, 0);
+                gtk_layout_put((widget), background_town, 12+15, 0);
             x_width = 138;
             x_offset = 12+15;
             break; 
         case PRESET_NOW_PLUS_TWO:
             snprintf(buffer, sizeof(buffer) - 1, "%s%s", IMAGES_PATH, PRESET_NOW_BACKGROUND_TOWN_PLUS_TWO);
-//            background_town = gtk_image_new_from_file (buffer);
+            background_town = gtk_image_new_from_file (buffer);
             if (background_town)
-                gtk_fixed_put(GTK_FIXED(widget), background_town, 12+15, 0);
+         //       gtk_fixed_put(GTK_FIXED(widget), background_town, 12+15, 0);
+                gtk_layout_put((widget), background_town, 12+15, 0);
             x_width = 140;
             x_offset = 12+15;
             break;
         case PRESET_NOW_PLUS_THREE_V:
             snprintf(buffer, sizeof(buffer) - 1, "%s%s", IMAGES_PATH, PRESET_NOW_BACKGROUND_TOWN_PLUS_THREE_V);
-//            background_town = gtk_image_new_from_file (buffer);
+            background_town = gtk_image_new_from_file (buffer);
             if (background_town)
-                gtk_fixed_put(GTK_FIXED(widget), background_town, 0, 0);
+//                gtk_fixed_put(GTK_FIXED(widget), background_town, 0, 0);
+                gtk_layout_put(GTK_FIXED(widget), background_town, 0, 0);
             x_width = 210;
             x_offset = 0;
             break;
         default:
         case PRESET_NOW:
             snprintf(buffer, sizeof(buffer) - 1, "%s%s", IMAGES_PATH, PRESET_NOW_BACKGROUND_TOWN);
-//            background_town = gtk_image_new_from_file (buffer);
+            background_town = gtk_image_new_from_file (buffer);
             if (background_town)
-                gtk_fixed_put(GTK_FIXED(widget), background_town, 12+15, 0);
+//                gtk_fixed_put(GTK_FIXED(widget), background_town, 12+15, 0);
+                gtk_layout_put((widget), background_town, 12+15, 0);
             x_width = 140;
             x_offset = 12+15;
             break;
@@ -591,9 +630,7 @@ next_station_preset_now(gint layout)
         g_signal_connect(station_name_btn, "button-press-event",
                     G_CALLBACK(change_station_next), NULL);
     }
-    
     /* Create station name */
-#if 0
     station_text = gtk_label_new(NULL);
     if(app->config->current_station_id){
         memset(buffer, 0, sizeof(buffer));
@@ -619,16 +656,21 @@ next_station_preset_now(gint layout)
         station_text = NULL;
         shadow_station_text = NULL;
     }
-#endif
+
     if (station_name_btn)
-        gtk_fixed_put(GTK_FIXED(widget), station_name_btn, x_offset, 0);
+//        gtk_fixed_put(GTK_FIXED(widget), station_name_btn, x_offset, 0);
+        gtk_layout_put((widget), station_name_btn, x_offset, 0);
+    gtk_widget_show(station_name_btn);
     if (shadow_station_text)
-        gtk_fixed_put(GTK_FIXED(widget), shadow_station_text, x_offset+2+1, 17+1);
+//        gtk_fixed_put(GTK_FIXED(widget), shadow_station_text, x_offset+2+1, 17+1);
+        gtk_layout_put((widget), shadow_station_text, x_offset+2+1, 17+1);
     if (station_text)
-        gtk_fixed_put(GTK_FIXED(widget), station_text, x_offset+1+1,17);
+//        gtk_fixed_put(GTK_FIXED(widget), station_text, x_offset+1+1,17);
+        gtk_layout_put((widget), station_text, x_offset+1+1,17);
 #ifdef DEBUGFUNCTIONCALL
     END_FUNCTION;
 #endif
+   gtk_widget_show_all(widget);
     return widget;
 }
 
@@ -641,10 +683,9 @@ fill_weather_day_button_presets(WDB *new_day_button, const char *text, const cha
     gchar       buffer[2048];
     GdkPixbuf   *icon_buffer;
     gchar       *begin_of_string;
-#ifdef DEBUGFUNCTIONCALL
+//#ifdef DEBUGFUNCTIONCALL
     START_FUNCTION;
-#endif
-
+//#endif
     /* create day label */
     new_day_button->label = gtk_label_new(NULL);
     gtk_label_set_markup(GTK_LABEL(new_day_button->label), text);
@@ -656,7 +697,7 @@ fill_weather_day_button_presets(WDB *new_day_button, const char *text, const cha
         set_font(new_day_button->label, PRESET_BIG_FONT, -1);
     gtk_widget_set_size_request(new_day_button->label, 140, 52);
 
-#if 0
+
     /* create wind text */
     new_day_button->wind_text = gtk_label_new(NULL);
     memset(buffer, 0, sizeof(buffer));
@@ -669,7 +710,7 @@ fill_weather_day_button_presets(WDB *new_day_button, const char *text, const cha
     /* Set font size for label */
     set_font(new_day_button->wind_text, PRESET_WIND_FONT, -1);
     gtk_widget_set_size_request(new_day_button->wind_text, 30, 30);
-#endif
+
    /* create day icon buffer */
     icon_buffer =
           gdk_pixbuf_new_from_file_at_size(icon,
@@ -681,7 +722,7 @@ fill_weather_day_button_presets(WDB *new_day_button, const char *text, const cha
         new_day_button->icon_image = create_icon_widget(icon_buffer, icon, PRESET_NORMAL_IMAGE_SIZE, &app->clutter_objects_in_main_form);
     else
         new_day_button->icon_image = NULL;
-#if 0
+
     memset(buffer, 0, sizeof(buffer));
     switch (wind_direction){
        case TO_SOUTH:
@@ -729,6 +770,7 @@ fill_weather_day_button_presets(WDB *new_day_button, const char *text, const cha
            begin_of_string = strstr(buffer,".png"); 
            snprintf(begin_of_string, sizeof(buffer) - strlen(buffer) - 1, "%s","_warning.png");
         }
+
         /* create day icon buffer */
         icon_buffer =
           gdk_pixbuf_new_from_file(buffer,
@@ -741,11 +783,10 @@ fill_weather_day_button_presets(WDB *new_day_button, const char *text, const cha
         else
             new_day_button->wind = NULL;
     }
-#endif
     new_day_button->box  = gtk_fixed_new();
-#ifdef DEBUGFUNCTIONCALL
+//#ifdef DEBUGFUNCTIONCALL
     END_FUNCTION;
-#endif
+//#endif
 }
 /**********************************************************************************************/
 void
@@ -756,10 +797,9 @@ fill_weather_day_button_preset_now(WDB *new_day_button, const char *text, const
     gchar       buffer[2048];
     GdkPixbuf   *icon_buffer;
     gchar       *begin_of_string;
-#ifdef DEBUGFUNCTIONCALL
+//#ifdef DEBUGFUNCTIONCALL
     START_FUNCTION;
-#endif
-#if 0
+//#endif
     /* create day label */
     new_day_button->label = gtk_label_new(NULL);
     gtk_label_set_markup(GTK_LABEL(new_day_button->label), text);
@@ -770,6 +810,7 @@ fill_weather_day_button_preset_now(WDB *new_day_button, const char *text, const
     else
         set_font(new_day_button->label, PRESET_BIG_FONT, -1);
     gtk_widget_set_size_request(new_day_button->label, 140, 52);
+
 /*        gtk_widget_set_name(new_day_button->label, "day_label");*/
     /* create shadow of day label */
     /* check for memcpy operation */
@@ -801,7 +842,7 @@ fill_weather_day_button_preset_now(WDB *new_day_button, const char *text, const
     /* Set font size for label */
     set_font(new_day_button->wind_text, PRESET_WIND_FONT, -1);
     gtk_widget_set_size_request(new_day_button->wind_text, 30, 30);
-#endif
+
    /* create day icon buffer */
     icon_buffer =
           gdk_pixbuf_new_from_file_at_size(icon,
@@ -856,16 +897,16 @@ fill_weather_day_button_preset_now(WDB *new_day_button, const char *text, const
                     wind_speed = wind_speed * 1.6;
                     break;
         }
-/*	
         if (wind_speed < STRONG_WIND)
-//            new_day_button->wind = gtk_image_new_from_file (buffer);
+            new_day_button->wind = gtk_image_new_from_file (buffer);
         else{
            begin_of_string = strstr(buffer,".png"); 
            snprintf(begin_of_string, sizeof(buffer) - strlen(buffer) - 1, "%s","_warning.png");
-//           new_day_button->wind = gtk_image_new_from_file (buffer);
+           new_day_button->wind = gtk_image_new_from_file (buffer);
         }
-*/	
     }
-    new_day_button->box  = gtk_fixed_new();
+ //   new_day_button->box  = gtk_fixed_new();
+    new_day_button->box  = gtk_layout_new(NULL, NULL);
+    realize(new_day_button->box);
 }
 /*******************************************************************************/
